summaryrefslogtreecommitdiffstats
path: root/ash/root_window_controller.h
diff options
context:
space:
mode:
Diffstat (limited to 'ash/root_window_controller.h')
-rw-r--r--ash/root_window_controller.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/ash/root_window_controller.h b/ash/root_window_controller.h
index 8bdbdb2..a3d99a3 100644
--- a/ash/root_window_controller.h
+++ b/ash/root_window_controller.h
@@ -87,8 +87,8 @@ class ASH_EXPORT RootWindowController : public ShellObserver {
// Returns a RootWindowController of the window's root window.
static RootWindowController* ForWindow(const aura::Window* window);
- // Returns the RootWindowController of the active root window.
- static internal::RootWindowController* ForActiveRootWindow();
+ // Returns the RootWindowController of the target root window.
+ static internal::RootWindowController* ForTargetRootWindow();
aura::RootWindow* root_window() { return root_window_.get(); }